@@ -524,7 +524,11 @@ TStateModel* Read_VAR_Specification(FILE *f, char *filename)
   if (!f_in) return (TStateModel*)NULL;
 
   // Read Markov specifications
-  if (!(sv=ReadMarkovSpecification(f_in,(char*)NULL))) return (TStateModel*)NULL;
+  if (!(sv=ReadMarkovSpecification(f_in,(char*)NULL)))
+    {
+      if (!f) fclose(f_in);
+      return (TStateModel*)NULL;
+    }
 
   //=== Sizes ===//
   nvars=ReadInteger_VARio(f_in,"//== Number Variables ==//");
@@ -536,6 +540,7 @@ TStateModel* Read_VAR_Specification(FILE *f, char *filename)
   if (nstates != sv->nstates)
     {
       dw_UserError("Read_VAR_Specification():  different values for nstates.");
+      if (!f) fclose(f_in);
       return (TStateModel*)NULL;
     }
 
@@ -842,6 +847,7 @@ int Read_VAR_Parameters(FILE *f, char *filename, char *header, TStateModel *mode
 	{
 	  ReadError_VARio(idbuffer);
 	  dw_free(idbuffer);
+      if (!f) fclose(f_in);
 	  return 0;
 	}
       dw_free(idbuffer);
@@ -852,6 +858,7 @@ int Read_VAR_Parameters(FILE *f, char *filename, char *header, TStateModel *mode
 	{
 	  ReadError_VARio(idbuffer);
 	  dw_free(idbuffer);
+      if (!f) fclose(f_in);
 	  return 0;
 	}
       dw_free(idbuffer);
@@ -862,10 +869,12 @@ int Read_VAR_Parameters(FILE *f, char *filename, char *header, TStateModel *mode
 	{
 	  ReadError_VARio(idbuffer);
 	  dw_free(idbuffer);
+      if (!f) fclose(f_in);
 	  return 0;
 	}
       dw_free(idbuffer);
     }
+  if (!f) fclose(f_in);
 
   // Set A0, Aplus, and Zeta
   for (j=0; j < p->nvars; j++)
@@ -931,21 +940,21 @@ int Read_VAR_ParametersFlat(FILE *f_in, TStateModel *model)
       for (j=0; j < p->nvars; j++)
 	for (i=0; i < p->nvars; i++)
 	  if (fscanf(f_in," %lf ",&ElementM(A0[s],i,j)) != 1)
-	    goto ERROR;
+	    goto ERRORCOND;
 
       Aplus[s]=CreateMatrix(p->npre,p->nvars);
       for (j=0; j < p->nvars; j++)
 	for (i=0; i < p->npre; i++)
 	  if (fscanf(f_in," %lf ",&ElementM(Aplus[s],i,j)) != 1)
-	    goto ERROR;
+	    goto ERRORCOND;
 
       Zeta[s]=CreateVector(p->nvars);
       for (j=0; j < p->nvars; j++)
 	if (fscanf(f_in," %lf ",&ElementV(Zeta[s],j)) != 1)
-	  goto ERROR;
+	  goto ERRORCOND;
 	else
 	  if (ElementV(Zeta[s],j) < 0.0)
-	    goto ERROR;
+	    goto ERRORCOND;
     }
 
   // Set A0, Aplus, and Zeta
@@ -970,7 +979,7 @@ int Read_VAR_ParametersFlat(FILE *f_in, TStateModel *model)
   ThetaChanged(model);
   rtrn=1;
 
- ERROR:
+ ERRORCOND:
 
   // Free memory
   dw_FreeArray(A0);
@@ -1045,9 +1054,13 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
 #if defined(MATLAB_MEX_FILE)
   MATFile *matFile;
 #else
+# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
+  size_t dims_i[3];
+#else
+  int dims_i[3];
+#endif
   mat_t *matFile;
   matvar_t *towrite;
-  int dims_i[3];
 #endif
 
   char *fullFilename = (char *)mxMalloc(strlen(out_tag) + strlen(".mat") - 1);
@@ -1056,8 +1069,14 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
 #if defined(MATLAB_MEX_FILE)
   matFile = matOpen(fullFilename, "wz");
 #else
-  matFile = Mat_Open(fullFilename, MAT_ACC_RDWR);
+  matFile = Mat_Create(fullFilename, NULL);
 #endif
+  if (matFile == NULL)
+    {
+      mexPrintf("Error opening mat file %s in Write_VAR_Parameters_Mat.\n", fullFilename);
+      mxFree(fullFilename);
+      dw_exit(0);
+    }
   mxFree(fullFilename);
 
   A0 = MakeA0_All(A0, p);
@@ -1083,11 +1102,15 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<3; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("A0", MAT_C_DOUBLE, MAT_T_DOUBLE, 3, dims_i, data, 0);
-  status = Mat_VarWrite(matFile, towrite, 0);
+# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
+  status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
+#else
+  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
+#endif
 #endif
   if (status != 0)
     {
-      mexPrintf("Error writing A0 to matfile in dw_PrintMatrix_Mat.\n");
+      mexPrintf("Error writing A0 to matfile in Write_VAR_Parameters_Mat.\n");
       dw_exit(0);
     }
 
@@ -1108,11 +1131,15 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<2; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("Aplus", MAT_C_DOUBLE, MAT_T_DOUBLE, 3, dims_i, data, 0);
-  status = Mat_VarWrite(matFile, towrite, 0);
+# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
+  status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
+#else
+  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
+#endif
 #endif
   if (status != 0)
     {
-      mexPrintf("Error writing Aplus to matfile in dw_PrintMatrix_Mat.\n");
+      mexPrintf("Error writing Aplus to matfile in Write_VAR_Parameters_Mat.\n");
       dw_exit(0);
     }
 
@@ -1133,11 +1160,15 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<2; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("Zeta", MAT_C_DOUBLE, MAT_T_DOUBLE, 3, dims_i, data, 0);
-  status = Mat_VarWrite(matFile, towrite, 0);
+# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
+  status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
+#else
+  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
+#endif
 #endif
   if (status != 0)
     {
-      mexPrintf("Error writing Zeta to matfile in dw_PrintMatrix_Mat.\n");
+      mexPrintf("Error writing Zeta to matfile in Write_VAR_Parameters_Mat.\n");
       dw_exit(0);
     }
 
@@ -1158,11 +1189,15 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<3; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("Q", MAT_C_DOUBLE, MAT_T_DOUBLE, 2, dims_i, data, 0);
-  status = Mat_VarWrite(matFile, towrite, 0);
+# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
+  status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
+#else
+  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
+#endif
 #endif
   if (status != 0)
     {
-      mexPrintf("Error writing Q to matfile in dw_PrintMatrix_Mat.\n");
+      mexPrintf("Error writing Q to matfile in Write_VAR_Parameters_Mat.\n");
       dw_exit(0);
     }
 
@@ -1575,6 +1610,7 @@ int Read_VAR_Parameters_Original(FILE *f, char *filename, char *header, TStateMo
 	{
 	  ReadError_VARio(idbuffer);
 	  dw_free(idbuffer);
+      if (!f) fclose(f_in);
 	  return 0;
 	}
       dw_free(idbuffer);
@@ -1585,6 +1621,7 @@ int Read_VAR_Parameters_Original(FILE *f, char *filename, char *header, TStateMo
 	{
 	  ReadError_VARio(idbuffer);
 	  dw_free(idbuffer);
+      if (!f) fclose(f_in);
 	  return 0;
 	}
       dw_free(idbuffer);
@@ -1595,10 +1632,12 @@ int Read_VAR_Parameters_Original(FILE *f, char *filename, char *header, TStateMo
 	{
 	  ReadError_VARio(idbuffer);
 	  dw_free(idbuffer);
+      if (!f) fclose(f_in);
 	  return 0;
 	}
       dw_free(idbuffer);
     }
+  if (!f) fclose(f_in);
 
   // Set A0, Aplus, and Zeta
   for (j=0; j < p->nvars; j++)
