@@ -69,6 +69,7 @@ SimResults::~SimResults()
 for(int i= 0;i<getNumSets();i++){
 delete data[i];
 delete shocks[i];
+delete start[i];
 }
 }
 
@@ -76,7 +77,7 @@ delete shocks[i];
 #line 36 "./decision_rule.cweb"
 ;
 /*5:*/
-#line 109 "./decision_rule.cweb"
+#line 110 "./decision_rule.cweb"
 
 void SimResults::simulate(int num_sim,const DecisionRule&dr,const Vector&start,
 const TwoDMatrix&vcov,Journal&journal)
@@ -96,7 +97,7 @@ rec<<"I had to throw "<<thrown<<" simulations away due to Nan or Inf"<<endrec;
 #line 37 "./decision_rule.cweb"
 ;
 /*6:*/
-#line 128 "./decision_rule.cweb"
+#line 129 "./decision_rule.cweb"
 
 void SimResults::simulate(int num_sim,const DecisionRule&dr,const Vector&start,
 const TwoDMatrix&vcov)
@@ -120,9 +121,9 @@ gr.run();
 #line 38 "./decision_rule.cweb"
 ;
 /*7:*/
-#line 151 "./decision_rule.cweb"
+#line 152 "./decision_rule.cweb"
 
-bool SimResults::addDataSet(TwoDMatrix*d,ExplicitShockRealization*sr)
+bool SimResults::addDataSet(TwoDMatrix*d,ExplicitShockRealization*sr,const ConstVector&st)
 {
 KORD_RAISE_IF(d->nrows()!=num_y,
 "Incompatible number of rows for SimResults::addDataSets");
@@ -133,6 +134,10 @@ if(d->isFinite()){
 data.push_back(new TwoDMatrix((const TwoDMatrix&)(*d),num_burn,num_per));
 shocks.push_back(new ExplicitShockRealization(
 ConstTwoDMatrix(sr->getShocks(),num_burn,num_per)));
+if(num_burn==0)
+start.push_back(new Vector(st));
+else
+start.push_back(new Vector(ConstVector(*d,num_burn-1)));
 ret= true;
 }
 
@@ -145,7 +150,7 @@ return ret;
 #line 39 "./decision_rule.cweb"
 ;
 /*8:*/
-#line 172 "./decision_rule.cweb"
+#line 177 "./decision_rule.cweb"
 
 void SimResults::writeMat(const char*base,const char*lname)const
 {
@@ -162,7 +167,7 @@ Mat_Close(matfd);
 #line 40 "./decision_rule.cweb"
 ;
 /*9:*/
-#line 187 "./decision_rule.cweb"
+#line 192 "./decision_rule.cweb"
 
 void SimResults::writeMat(mat_t*fd,const char*lname)const
 {
@@ -181,7 +186,7 @@ m.writeMat(fd,tmp);
 #line 41 "./decision_rule.cweb"
 ;
 /*10:*/
-#line 202 "./decision_rule.cweb"
+#line 207 "./decision_rule.cweb"
 
 void SimResultsStats::simulate(int num_sim,const DecisionRule&dr,
 const Vector&start,
@@ -205,7 +210,7 @@ calcVcov();
 #line 42 "./decision_rule.cweb"
 ;
 /*11:*/
-#line 222 "./decision_rule.cweb"
+#line 227 "./decision_rule.cweb"
 
 void SimResultsStats::writeMat(mat_t*fd,const char*lname)const
 {
@@ -221,7 +226,7 @@ ConstTwoDMatrix(vcov).writeMat(fd,tmp);
 #line 43 "./decision_rule.cweb"
 ;
 /*12:*/
-#line 234 "./decision_rule.cweb"
+#line 239 "./decision_rule.cweb"
 
 void SimResultsStats::calcMean()
 {
@@ -241,7 +246,7 @@ mean.add(mult,col);
 #line 44 "./decision_rule.cweb"
 ;
 /*13:*/
-#line 250 "./decision_rule.cweb"
+#line 255 "./decision_rule.cweb"
 
 void SimResultsStats::calcVcov()
 {
@@ -270,7 +275,7 @@ vcov.infs();
 #line 45 "./decision_rule.cweb"
 ;
 /*14:*/
-#line 275 "./decision_rule.cweb"
+#line 280 "./decision_rule.cweb"
 
 void SimResultsDynamicStats::simulate(int num_sim,const DecisionRule&dr,
 const Vector&start,
@@ -293,7 +298,7 @@ calcVariance();
 #line 46 "./decision_rule.cweb"
 ;
 /*15:*/
-#line 294 "./decision_rule.cweb"
+#line 299 "./decision_rule.cweb"
 
 void SimResultsDynamicStats::writeMat(mat_t*fd,const char*lname)const
 {
@@ -308,7 +313,7 @@ ConstTwoDMatrix(variance).writeMat(fd,tmp);
 #line 47 "./decision_rule.cweb"
 ;
 /*16:*/
-#line 305 "./decision_rule.cweb"
+#line 310 "./decision_rule.cweb"
 
 void SimResultsDynamicStats::calcMean()
 {
@@ -329,7 +334,7 @@ meanj.add(mult,col);
 #line 48 "./decision_rule.cweb"
 ;
 /*17:*/
-#line 322 "./decision_rule.cweb"
+#line 327 "./decision_rule.cweb"
 
 void SimResultsDynamicStats::calcVariance()
 {
@@ -357,7 +362,7 @@ variance.infs();
 #line 49 "./decision_rule.cweb"
 ;
 /*18:*/
-#line 346 "./decision_rule.cweb"
+#line 351 "./decision_rule.cweb"
 
 void SimResultsIRF::simulate(const DecisionRule&dr,Journal&journal)
 {
@@ -379,7 +384,7 @@ calcVariances();
 #line 50 "./decision_rule.cweb"
 ;
 /*19:*/
-#line 364 "./decision_rule.cweb"
+#line 369 "./decision_rule.cweb"
 
 void SimResultsIRF::simulate(const DecisionRule&dr)
 {
@@ -397,7 +402,7 @@ gr.run();
 #line 51 "./decision_rule.cweb"
 ;
 /*20:*/
-#line 378 "./decision_rule.cweb"
+#line 383 "./decision_rule.cweb"
 
 void SimResultsIRF::calcMeans()
 {
@@ -413,7 +418,7 @@ means.mult(1.0/data.size());
 #line 52 "./decision_rule.cweb"
 ;
 /*21:*/
-#line 390 "./decision_rule.cweb"
+#line 395 "./decision_rule.cweb"
 
 void SimResultsIRF::calcVariances()
 {
@@ -436,7 +441,7 @@ variances.infs();
 #line 53 "./decision_rule.cweb"
 ;
 /*22:*/
-#line 409 "./decision_rule.cweb"
+#line 414 "./decision_rule.cweb"
 
 void SimResultsIRF::writeMat(mat_t*fd,const char*lname)const
 {
@@ -451,7 +456,7 @@ variances.writeMat(fd,tmp);
 #line 54 "./decision_rule.cweb"
 ;
 /*23:*/
-#line 420 "./decision_rule.cweb"
+#line 425 "./decision_rule.cweb"
 
 void RTSimResultsStats::simulate(int num_sim,const DecisionRule&dr,const Vector&start,
 const TwoDMatrix&v,Journal&journal)
@@ -476,7 +481,7 @@ rec1<<"This affected "<<incomplete_simulations<<" out of "
 #line 55 "./decision_rule.cweb"
 ;
 /*24:*/
-#line 441 "./decision_rule.cweb"
+#line 446 "./decision_rule.cweb"
 
 void RTSimResultsStats::simulate(int num_sim,const DecisionRule&dr,const Vector&start,
 const TwoDMatrix&vcov)
@@ -500,7 +505,7 @@ gr.run();
 #line 56 "./decision_rule.cweb"
 ;
 /*25:*/
-#line 461 "./decision_rule.cweb"
+#line 466 "./decision_rule.cweb"
 
 void RTSimResultsStats::writeMat(mat_t*fd,const char*lname)
 {
@@ -516,7 +521,7 @@ ConstTwoDMatrix(vcov).writeMat(fd,tmp);
 #line 57 "./decision_rule.cweb"
 ;
 /*26:*/
-#line 473 "./decision_rule.cweb"
+#line 478 "./decision_rule.cweb"
 
 IRFResults::IRFResults(const DynamicModel&mod,const DecisionRule&dr,
 const SimResults&control,const vector<int> &ili,
@@ -547,7 +552,7 @@ irf_res[2*ii+1]->simulate(dr,journal);
 #line 58 "./decision_rule.cweb"
 ;
 /*27:*/
-#line 500 "./decision_rule.cweb"
+#line 505 "./decision_rule.cweb"
 
 IRFResults::~IRFResults()
 {
@@ -559,7 +564,7 @@ delete irf_res[i];
 #line 59 "./decision_rule.cweb"
 ;
 /*28:*/
-#line 508 "./decision_rule.cweb"
+#line 513 "./decision_rule.cweb"
 
 void IRFResults::writeMat(mat_t*fd,const char*prefix)const
 {
@@ -578,7 +583,7 @@ irf_res[2*i+1]->writeMat(fd,tmp);
 #line 60 "./decision_rule.cweb"
 ;
 /*29:*/
-#line 523 "./decision_rule.cweb"
+#line 528 "./decision_rule.cweb"
 
 void SimulationWorker::operator()()
 {
@@ -586,7 +591,7 @@ ExplicitShockRealization*esr= new ExplicitShockRealization(sr,np);
 TwoDMatrix*m= dr.simulate(em,np,st,*esr);
 {
 SYNCHRO syn(&res,"simulation");
-res.addDataSet(m,esr);
+res.addDataSet(m,esr,st);
 }
 }
 
@@ -594,20 +599,18 @@ res.addDataSet(m,esr);
 #line 61 "./decision_rule.cweb"
 ;
 /*30:*/
-#line 537 "./decision_rule.cweb"
+#line 542 "./decision_rule.cweb"
 
 void SimulationIRFWorker::operator()()
 {
 ExplicitShockRealization*esr= 
 new ExplicitShockRealization(res.control.getShocks(idata));
 esr->addToShock(ishock,0,imp);
-const TwoDMatrix&data= res.control.getData(idata);
-ConstVector st(data,res.control.getNumBurn());
-TwoDMatrix*m= dr.simulate(em,np,st,*esr);
+TwoDMatrix*m= dr.simulate(em,np,res.control.getStart(idata),*esr);
 m->add(-1.0,res.control.getData(idata));
 {
 SYNCHRO syn(&res,"simulation");
-res.addDataSet(m,esr);
+res.addDataSet(m,esr,res.control.getStart(idata));
 }
 }
 
@@ -615,7 +618,7 @@ res.addDataSet(m,esr);
 #line 62 "./decision_rule.cweb"
 ;
 /*31:*/
-#line 554 "./decision_rule.cweb"
+#line 557 "./decision_rule.cweb"
 
 void RTSimulationWorker::operator()()
 {
@@ -625,7 +628,7 @@ int nu= dr.nexog();
 const Vector&ysteady= dr.getSteady();
 
 /*32:*/
-#line 576 "./decision_rule.cweb"
+#line 579 "./decision_rule.cweb"
 
 Vector dyu(ypart.nys()+nu);
 ConstVector ystart_pred(ystart,ypart.nstat,ypart.nys());
@@ -636,10 +639,10 @@ Vector y(nc.getDim());
 ConstVector ypred(y,ypart.nstat,ypart.nys());
 
 /*:32*/
-#line 562 "./decision_rule.cweb"
+#line 565 "./decision_rule.cweb"
 ;
 /*33:*/
-#line 586 "./decision_rule.cweb"
+#line 589 "./decision_rule.cweb"
 
 int ip= 0;
 dy= ystart_pred;
@@ -650,10 +653,10 @@ if(ip>=res.num_burn)
 nc.update(y);
 
 /*:33*/
-#line 563 "./decision_rule.cweb"
+#line 566 "./decision_rule.cweb"
 ;
 /*34:*/
-#line 596 "./decision_rule.cweb"
+#line 599 "./decision_rule.cweb"
 
 while(y.isFinite()&&ip<res.num_burn+res.num_per){
 ip++;
@@ -665,7 +668,7 @@ nc.update(y);
 }
 
 /*:34*/
-#line 564 "./decision_rule.cweb"
+#line 567 "./decision_rule.cweb"
 ;
 {
 SYNCHRO syn(&res,"rtsimulation");
@@ -681,7 +684,7 @@ res.thrown_periods+= res.num_per-ip;
 #line 63 "./decision_rule.cweb"
 ;
 /*35:*/
-#line 609 "./decision_rule.cweb"
+#line 612 "./decision_rule.cweb"
 
 void RandomShockRealization::choleskyFactor(const TwoDMatrix&v)
 {
@@ -701,7 +704,7 @@ KORD_RAISE_IF(info!=0,
 #line 64 "./decision_rule.cweb"
 ;
 /*36:*/
-#line 627 "./decision_rule.cweb"
+#line 630 "./decision_rule.cweb"
 
 void RandomShockRealization::schurFactor(const TwoDMatrix&v)
 {
@@ -713,7 +716,7 @@ ssd.getFactor(factor);
 #line 65 "./decision_rule.cweb"
 ;
 /*37:*/
-#line 635 "./decision_rule.cweb"
+#line 638 "./decision_rule.cweb"
 
 void RandomShockRealization::get(int n,Vector&out)
 {
@@ -731,7 +734,7 @@ factor.multaVec(out,ConstVector(d));
 #line 66 "./decision_rule.cweb"
 ;
 /*38:*/
-#line 649 "./decision_rule.cweb"
+#line 652 "./decision_rule.cweb"
 
 ExplicitShockRealization::ExplicitShockRealization(ShockRealization&sr,
 int num_per)
@@ -747,7 +750,7 @@ sr.get(j,jcol);
 #line 67 "./decision_rule.cweb"
 ;
 /*39:*/
-#line 661 "./decision_rule.cweb"
+#line 664 "./decision_rule.cweb"
 
 void ExplicitShockRealization::get(int n,Vector&out)
 {
@@ -762,7 +765,7 @@ out= icol;
 #line 68 "./decision_rule.cweb"
 ;
 /*40:*/
-#line 672 "./decision_rule.cweb"
+#line 675 "./decision_rule.cweb"
 
 void ExplicitShockRealization::addToShock(int ishock,int iper,double val)
 {
@@ -777,7 +780,7 @@ shocks.get(ishock,j)+= val;
 #line 69 "./decision_rule.cweb"
 ;
 /*41:*/
-#line 683 "./decision_rule.cweb"
+#line 686 "./decision_rule.cweb"
 
 void GenShockRealization::get(int n,Vector&out)
 {
