@@ -538,7 +538,7 @@ int newton_iter_total;
 #line 54 "./decision_rule.hweb"
 ;
 /*26:*/
-#line 699 "./decision_rule.hweb"
+#line 700 "./decision_rule.hweb"
 
 class ExplicitShockRealization;
 class SimResults{
@@ -548,6 +548,7 @@ int num_per;
 int num_burn;
 vector<TwoDMatrix*> data;
 vector<ExplicitShockRealization*> shocks;
+vector<Vector*> start;
 public:
 SimResults(int ny,int nper,int nburn= 0)
 :num_y(ny),num_per(nper),num_burn(nburn){}
@@ -566,7 +567,9 @@ const TwoDMatrix&getData(int i)const
 {return*(data[i]);}
 const ExplicitShockRealization&getShocks(int i)const
 {return*(shocks[i]);}
-bool addDataSet(TwoDMatrix*d,ExplicitShockRealization*sr);
+const Vector&getStart(int i)const
+{return*(start[i]);}
+bool addDataSet(TwoDMatrix*d,ExplicitShockRealization*sr,const ConstVector&st);
 void writeMat(const char*base,const char*lname)const;
 void writeMat(mat_t*fd,const char*lname)const;
 };
@@ -575,7 +578,7 @@ void writeMat(mat_t*fd,const char*lname)const;
 #line 55 "./decision_rule.hweb"
 ;
 /*27:*/
-#line 734 "./decision_rule.hweb"
+#line 738 "./decision_rule.hweb"
 
 class SimResultsStats:public SimResults{
 protected:
@@ -596,7 +599,7 @@ void calcVcov();
 #line 56 "./decision_rule.hweb"
 ;
 /*28:*/
-#line 754 "./decision_rule.hweb"
+#line 758 "./decision_rule.hweb"
 
 class SimResultsDynamicStats:public SimResults{
 protected:
@@ -618,7 +621,7 @@ void calcVariance();
 #line 57 "./decision_rule.hweb"
 ;
 /*29:*/
-#line 778 "./decision_rule.hweb"
+#line 782 "./decision_rule.hweb"
 
 class SimulationIRFWorker;
 class SimResultsIRF:public SimResults{
@@ -646,7 +649,7 @@ void calcVariances();
 #line 58 "./decision_rule.hweb"
 ;
 /*30:*/
-#line 807 "./decision_rule.hweb"
+#line 811 "./decision_rule.hweb"
 
 class RTSimulationWorker;
 class RTSimResultsStats{
@@ -675,7 +678,7 @@ void writeMat(mat_t*fd,const char*lname);
 #line 59 "./decision_rule.hweb"
 ;
 /*31:*/
-#line 845 "./decision_rule.hweb"
+#line 849 "./decision_rule.hweb"
 
 class DynamicModel;
 class IRFResults{
@@ -694,7 +697,7 @@ void writeMat(mat_t*fd,const char*prefix)const;
 #line 60 "./decision_rule.hweb"
 ;
 /*32:*/
-#line 862 "./decision_rule.hweb"
+#line 866 "./decision_rule.hweb"
 
 class SimulationWorker:public THREAD{
 protected:
@@ -717,7 +720,7 @@ void operator()();
 #line 61 "./decision_rule.hweb"
 ;
 /*33:*/
-#line 885 "./decision_rule.hweb"
+#line 889 "./decision_rule.hweb"
 
 class SimulationIRFWorker:public THREAD{
 SimResultsIRF&res;
@@ -741,7 +744,7 @@ void operator()();
 #line 62 "./decision_rule.hweb"
 ;
 /*34:*/
-#line 910 "./decision_rule.hweb"
+#line 914 "./decision_rule.hweb"
 
 class RTSimulationWorker:public THREAD{
 protected:
@@ -764,7 +767,7 @@ void operator()();
 #line 63 "./decision_rule.hweb"
 ;
 /*35:*/
-#line 932 "./decision_rule.hweb"
+#line 936 "./decision_rule.hweb"
 
 class RandomShockRealization:virtual public ShockRealization{
 protected:
@@ -789,7 +792,7 @@ void schurFactor(const TwoDMatrix&v);
 #line 64 "./decision_rule.hweb"
 ;
 /*36:*/
-#line 955 "./decision_rule.hweb"
+#line 959 "./decision_rule.hweb"
 
 class ExplicitShockRealization:virtual public ShockRealization{
 TwoDMatrix shocks;
@@ -815,7 +818,7 @@ void print()const
 #line 65 "./decision_rule.hweb"
 ;
 /*37:*/
-#line 985 "./decision_rule.hweb"
+#line 989 "./decision_rule.hweb"
 
 class GenShockRealization:public RandomShockRealization,public ExplicitShockRealization{
 public:
