@@ -1,12 +1,14 @@
 function CutSample(M_, options_, estim_params_)
-
-% function CutSample()
-% Takes a subset from metropolis
+% function CutSample(M_, options_, estim_params_)
+% Takes a subset from metropolis draws by storing the required information
+% like the first MH-file to be loaded and the first line in that file to be
+% loaded into the record structure saved on harddisk into the
+% _mh_history-file
 %
 % INPUTS
-%   options_         [structure]
-%   estim_params_    [structure]
-%   M_               [structure]
+%   M_               [structure]    Dynare model structure
+%   options_         [structure]    Dynare options structure
+%   estim_params_    [structure]    Parameter structure
 %
 % OUTPUTS
 %    none
@@ -14,7 +16,7 @@ function CutSample(M_, options_, estim_params_)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2005-2012 Dynare Team
+% Copyright (C) 2005-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -52,7 +54,7 @@ end
 TotalNumberOfMhFiles = sum(record.MhDraws(:,2));
 TotalNumberOfMhDraws = sum(record.MhDraws(:,1));
 MAX_nruns = ceil(options_.MaxNumberOfBytes/(npar+2)/8);
-FirstDraw = max(1,floor(options_.mh_drop*TotalNumberOfMhDraws));
+FirstDraw = max(1,floor(options_.mh_drop*TotalNumberOfMhDraws)+1);
 FirstMhFile = ceil(FirstDraw/MAX_nruns);
 FirstLine = FirstDraw-(FirstMhFile-1)*MAX_nruns;
 record.KeepedDraws.FirstMhFile = FirstMhFile;
@@ -64,15 +66,15 @@ if (TotalNumberOfMhFiles-1)-(FirstMhFile+1)+1 > 0
 elseif TotalNumberOfMhFiles == 1
     record.KeepedDraws.Distribution = [];
 elseif TotalNumberOfMhFiles == 2 && FirstMhFile > 1
-    record.KeepedDraws.Distribution = [MAX_nruns-FirstLine+1 ; record.MhDraws(end,3)];  
+    record.KeepedDraws.Distribution = [MAX_nruns-FirstLine+1 ; record.MhDraws(end,3)];
 end
 
 % Save updated mh-history file.
 update_last_mh_history_file(MetropolisFolder, ModelName, record);
 
-fprintf('Estimation::mcmc: Total number of MH draws: %d.\n',TotalNumberOfMhDraws);
+fprintf('Estimation::mcmc: Total number of MH draws per chain: %d.\n',TotalNumberOfMhDraws);
 fprintf('Estimation::mcmc: Total number of generated MH files: %d.\n',TotalNumberOfMhFiles);
 fprintf('Estimation::mcmc: I''ll use mh-files %d to %d.\n',FirstMhFile,TotalNumberOfMhFiles);
 fprintf('Estimation::mcmc: In MH-file number %d I''ll start at line %d.\n',FirstMhFile,FirstLine);
-fprintf('Estimation::mcmc: Finally I keep %d draws.\n',TotalNumberOfMhDraws-FirstDraw);
+fprintf('Estimation::mcmc: Finally I keep %d draws per chain.\n',TotalNumberOfMhDraws-FirstDraw+1);
 skipline()
\ No newline at end of file
