@@ -51,7 +51,7 @@ else
                     addpath(mexpath);
                 end
             end
-        else
+        elseif matlab_ver_less_than('9.4')
             tmp = [dynareroot '../mex/matlab/win64-7.8-9.3/'];
             if exist(tmp, 'dir')
                 mexpath = tmp;
@@ -59,6 +59,14 @@ else
                     addpath(mexpath);
                 end
             end
+        else
+            tmp = [dynareroot '../mex/matlab/win64-9.4-9.5/'];
+            if exist(tmp, 'dir')
+                mexpath = tmp;
+                if modifypath
+                    addpath(mexpath);
+                end
+            end
         end
     end
     % Add OS X 64bits specific paths for Dynare Mac package
