@@ -75,16 +75,11 @@ p = {'/distributions/' ; ...
 % For functions that exist only under some Octave versions
 % or some MATLAB versions, and for which we provide some replacement functions
 
+% Replacements for rows(), columns(), vec() and issquare() (inexistent under MATLAB)
 if ~isoctave
-    % Replacements for rows(), columns() and issquare() (inexistent under MATLAB)
     p{end+1} = '/missing/rows_columns';
     p{end+1} = '/missing/issquare';
-    % Replacement for vec() (inexistent under MATLAB)
     p{end+1} = '/missing/vec';
-    if ~user_has_matlab_license('statistics_toolbox')
-        % Replacements for functions of the stats toolbox
-        p{end+1} = '/missing/stats/';
-    end
 end
 
 % ordeig() doesn't exist in Octave
@@ -92,22 +87,13 @@ if isoctave
     p{end+1} = '/missing/ordeig';
 end
 
-if isoctave && ~isequal(supported_octave_version(), version())
-    skipline()
-    warning(['This version of Octave is not supported. Consider installing ' ...
-             'version %s of Octave,\notherwise m files will be used instead ' ...
-             'of precompiled mex files and some features, like solution\n' ...
-             'of models approximated at third order, will not be available.'], supported_octave_version())
-    skipline()
-end
-
 % ilu is missing in Octave < 4.0
 if isoctave && octave_ver_less_than('4.0')
     p{end+1} = '/missing/ilu';
 end
 
-% corrcoef with two outputs is missing in Octave (ticket #796)
-if isoctave && ~user_has_octave_forge_package('nan')
+% corrcoef with two outputs is missing in Octave < 4.4 (ticket #796)
+if isoctave && octave_ver_less_than('4.4') && ~user_has_octave_forge_package('nan')
     p{end+1} = '/missing/corrcoef';
 end
 
@@ -118,6 +104,16 @@ if (isoctave && ~user_has_octave_forge_package('statistics')) ...
     p{end+1} = '/missing/nanmean';
 end
 
+% Replacements for functions of the MATLAB statistics toolbox
+% These functions were part of Octave < 4.4, they are now in the statistics Forge package
+if (isoctave && ~octave_ver_less_than('4.4') && ~user_has_octave_forge_package('statistics')) ...
+        || (~isoctave && ~user_has_matlab_license('statistics_toolbox'))
+    p{end+1} = '/missing/stats/';
+    if ~isoctave
+        p{end+1} = '/missing/stats-matlab/';
+    end
+end
+
 % Check if struct2array is available.
 if ~exist('struct2array')
     p{end+1} = '/missing/struct2array';
@@ -128,6 +124,16 @@ if isoctave || matlab_ver_less_than('9.3')
     p{end+1} = '/missing/isfile';
 end
 
+% strsplit is missing in Matlab<R2013a
+if ~isoctave && matlab_ver_less_than('8.1')
+    p{end+1} = '/missing/strsplit';
+end
+
+% isrow, iscolumn and ismatrix are missing in Matlab<R2010b
+if ~isoctave && matlab_ver_less_than('7.11')
+    p{end+1} = '/missing/is-row-column-matrix';
+end
+
 P = cellfun(@(c)[dynareroot(1:end-1) c], p, 'uni',false);
 
 % Get mex files folder(s)
@@ -245,4 +251,4 @@ end
 % Initialization of the dates and dseries classes (recursive).
 initialize_dseries_toolbox;
 
-cd(origin);
\ No newline at end of file
+cd(origin);
