@@ -1,6 +1,15 @@
 function yf=forcst2a(y0,dr,e)
-
-% Copyright (C) 2008-2010 Dynare Team
+% function yf=forcst2a(y0,dr,e)
+% computes forecasts based on first order model solution, assuming the absence of shocks
+% Inputs:
+%   - y0        [endo_nbr by maximum_endo_lag]          matrix of starting values
+%   - dr        [structure]                             structure with Dynare decision rules
+%   - e         [horizon by exo_nbr]                    matrix with shocks
+%
+% Outputs:
+%   - yf        [horizon+maximum_endo_lag,endo_nbr]               matrix of forecasts
+%
+% Copyright (C) 2008-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -19,13 +28,10 @@ function yf=forcst2a(y0,dr,e)
 
 global M_ options_
 
-Sigma_e_ = M_.Sigma_e;
 endo_nbr = M_.endo_nbr;
-exo_nbr = M_.exo_nbr;
 ykmin_ = M_.maximum_endo_lag;
 
 horizon = size(e,1);
-order = options_.order;
 
 k1 = [ykmin_:-1:1];
 k2 = dr.kstate(find(dr.kstate(:,2) <= ykmin_+1),[1 2]);
@@ -42,4 +48,3 @@ for i=ykmin_+(1:horizon)
 end
 
 yf(:,dr.order_var) = yf;
-
