@@ -11,7 +11,7 @@ function global_initialization()
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2003-2013 Dynare Team
+% Copyright (C) 2003-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -28,11 +28,15 @@ function global_initialization()
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-global oo_ M_ options_ estim_params_ bayestopt_ estimation_info ex0_ ys0_  ex_det0_
-
+global oo_ M_ options_ estim_params_ bayestopt_ estimation_info ex0_ ys0_ dataset_ dataset_info
 estim_params_ = [];
 bayestopt_ = [];
+dataset_=[];
+dataset_info=[];
 options_.datafile = '';
+options_.dirname = M_.fname;
+M_.dname = M_.fname;
+options_.dataset = [];
 options_.verbosity = 1;
 options_.terminal_condition = 0;
 options_.rplottype = 0;
@@ -54,10 +58,12 @@ options_.qz_zero_threshold = 1e-6;
 options_.lyapunov_complex_threshold = 1e-15;
 options_.solve_tolf = eps^(1/3);
 options_.solve_tolx = eps^(2/3);
-
+options_.dr_display_tol=1e-6;
+options_.minimal_workspace = 0;
 options_.dp.maxit = 3000;
-options_.steady.maxit = 10;
-options_.simul.maxit = 10;
+options_.steady.maxit = 50;
+options_.simul.maxit = 50;
+options_.simul.robust_lin_solve = 0;
 
 options_.mode_check.status = 0;
 options_.mode_check.neighbourhood_size = .5;
@@ -65,6 +71,8 @@ options_.mode_check.symmetric_plots = 1;
 options_.mode_check.number_of_points = 20;
 options_.mode_check.nolik = 0;
 
+options_.huge_number = 1e7;
+
 % Default number of threads for parallelized mex files.
 options_.threads.kronecker.A_times_B_kronecker_C = 1;
 options_.threads.kronecker.sparse_hessian_times_B_kronecker_C = 1;
@@ -101,6 +109,11 @@ options_.bvar_prior_mu = 2;
 options_.bvar_prior_omega = 1;
 options_.bvar_prior_flat = 0;
 options_.bvar_prior_train = 0;
+options_.bvar.conf_sig = 0.6;
+
+% Initialize the field that will contain the optimization algorigthm's options declared in the
+% estimation command (if anny).
+options_.optim_opt = [];
 
 % Optimization algorithm [6] gmhmaxlik
 gmhmaxlik.iterations = 3;
@@ -121,6 +134,8 @@ options_.graphics.line_width = 1;
 options_.graph_format = 'eps';
 options_.nodisplay = 0;
 options_.nograph = 0;
+options_.no_graph.posterior = 0;
+options_.no_graph.shock_decomposition = 0;
 options_.XTick = [];
 options_.XTickLabel = [];
 options_.console_mode = 0;
@@ -130,9 +145,7 @@ if isoctave
         options_.nodisplay = 1;
     end
 else
-    if isunix && (~usejava('jvm') || ...
-            ((matlab_ver_less_than('7.5') && sum(get(0,'ScreenSize'))==4) || ...
-            (~matlab_ver_less_than('7.5') && ~feature('ShowFigureWindows'))))
+    if isunix && (~usejava('jvm') || ~feature('ShowFigureWindows'))
         options_.console_mode = 1;
         options_.nodisplay = 1;
     end
@@ -144,17 +157,23 @@ options_.impulse_responses.plot_threshold=1e-10;
 options_.relative_irf = 0;
 options_.ar = 5;
 options_.hp_filter = 0;
+options_.one_sided_hp_filter = 0;
 options_.hp_ngrid = 512;
+options_.nodecomposition = 0;
 options_.nomoments = 0;
 options_.nocorr = 0;
 options_.periods = 0;
 options_.noprint = 0;
 options_.SpectralDensity.trigger = 0;
-options_.SpectralDensity.plot  = 1; 
-options_.SpectralDensity.cutoff  = 150; 
-options_.SpectralDensity.sdl = 0.01; 
+options_.SpectralDensity.plot  = 1;
+options_.SpectralDensity.cutoff  = 150;
+options_.SpectralDensity.sdl = 0.01;
 options_.nofunctions = false;
 
+options_.bandpass.indicator = 0;
+options_.bandpass.passband = [6; 32];
+options_.bandpass.K=12;
+
 % Extended path options
 %
 % Set debug flag
@@ -187,7 +206,12 @@ ep.innovation_distribution = 'gaussian';
 % Set flag for the seed
 ep.set_dynare_seed_to_default = 1;
 % Set algorithm for the perfect foresight solver
-ep.stack_solve_algo = 4;
+ep.stack_solve_algo = 7;
+ep.solve_algo = 9;
+% Number of replications
+ep.replic_nbr = 1;
+% Parallel execution of replications
+ep.parallel = false;
 % Stochastic extended path related options.
 ep.stochastic.method = '';
 ep.stochastic.algo = 0;
@@ -198,6 +222,8 @@ ep.stochastic.quadrature.pruned.status = 0;
 ep.stochastic.quadrature.pruned.relative = 1e-5;
 ep.stochastic.quadrature.pruned.level = 1e-5;
 ep.stochastic.hybrid_order = 0;
+% homotopic step in extended path simulations
+ep.stochastic.homotopic_steps = true;
 % Copy ep structure in options_ global structure
 options_.ep = ep;
 
@@ -219,27 +245,35 @@ particle.initial_state_prior_std = .1;
 % Set the default order of approximation of the model (perturbation).
 particle.perturbation = 2;
 % Set the default number of particles.
-particle.number_of_particles = 500;
+particle.number_of_particles = 5000;
 % Set the default approximation order (Smolyak)
 particle.smolyak_accuracy = 3;
 % By default we don't use pruning
 particle.pruning = 0;
-% Set default algorithm
-particle.algorithm = 'sequential_importance_particle_filter';
-% Set the Gaussian approximation method for Importance sampling
-particle.IS_approximation_method = 'unscented';
 % Set the Gaussian approximation method for particles distributions
 particle.approximation_method = 'unscented';
 % Set unscented parameters alpha, beta and kappa for gaussian approximation
-particle.unscented.alpha = .01;
+particle.unscented.alpha = 1;
 particle.unscented.beta = 2;
-particle.unscented.kappa = 0;
+particle.unscented.kappa = 1;
 % Configuration of resampling in case of particles
-particle.resampling.status = 'systematic'; % 'none', 'generic', 'smoothed'
-particle.resampling.neff_threshold = .5;
-% Choice of the resampling method
-particle.resampling.method1 = 'traditional' ;
-particle.resampling.method2 = 'kitagawa';
+particle.resampling.status.systematic = 1;
+particle.resampling.status.none = 0;
+particle.resampling.status.generic = 0;
+particle.resampling.threshold = .5;
+particle.resampling.method.kitagawa = 1;
+particle.resampling.method.smooth = 0;
+particle.resampling.method.stratified = 0;
+% Set default algorithm
+particle.filter_algorithm = 'sis';
+% Approximation of the proposal distribution
+particle.proposal_approximation.cubature = 0;
+particle.proposal_approximation.unscented = 1;
+particle.proposal_approximation.montecarlo = 0;
+% Approximation of the particle distribution
+particle.distribution_approximation.cubature = 0;
+particle.distribution_approximation.unscented = 1;
+particle.distribution_approximation.montecarlo = 0;
 % Number of partitions for the smoothed resampling method
 particle.resampling.number_of_partitions = 200;
 % Configuration of the mixture filters
@@ -248,11 +282,17 @@ particle.resampling.number_of_partitions = 200;
 particle.mixture_state_variables = 5 ;
 particle.mixture_structural_shocks = 1 ;
 particle.mixture_measurement_shocks = 1 ;
-% Online approach 
+% Online approach
 particle.liu_west_delta = 0.99 ;
 particle.liu_west_chol_sigma_bar = .01 ;
+% Options for setting the weights in conditional particle filters.
+particle.cpf_weights_method.amisanotristani = 1;
+particle.cpf_weights_method.murrayjonesparslow = 0;
 % Copy ep structure in options_ global structure
 options_.particle = particle;
+options_.rwgmh.init_scale = 1e-4 ;
+options_.rwgmh.scale_chain = 1 ;
+options_.rwgmh.scale_shock = 1e-5 ;
 
 % TeX output
 options_.TeX = 0;
@@ -262,7 +302,14 @@ options_.xls_sheet = 1; % Octave does not support the empty string, rather use f
 options_.xls_range = '';
 
 % Prior draws
+options_.prior_draws = 10000;
+
+% Prior posterior function sampling draws
+options_.sampling_draws = 500;
+
 options_.forecast = 0;
+options_.forecasts.conf_sig = 0.9;
+options_.conditional_forecast.conf_sig = 0.9;
 
 % Model
 options_.linear = 0;
@@ -271,11 +318,13 @@ options_.linear = 0;
 options_.stack_solve_algo = 0;
 options_.markowitz = 0.5;
 options_.minimal_solving_periods = 1;
+options_.endogenous_terminal_period = 0;
+options_.no_homotopy = 0;
 
 % Solution
 options_.order = 2;
 options_.pruning = 0;
-options_.solve_algo = 2;
+options_.solve_algo = 4;
 options_.linear = 0;
 options_.replic = 50;
 options_.simul_replic = 1;
@@ -297,7 +346,9 @@ options_.conditional_variance_decomposition = [];
 
 % Ramsey policy
 options_.ramsey_policy = 0;
+options_.instruments = [];
 options_.timeless = 0;
+options_.ramsey.maxit = 500;
 
 % estimation
 estimation_info.empty_prior = struct(...
@@ -344,16 +395,19 @@ estimation_info.measurement_error_corr.range_index = {};
 estimation_info.structural_innovation_corr_prior_index = {};
 estimation_info.structural_innovation_corr_options_index = {};
 estimation_info.structural_innovation_corr.range_index = {};
-options_.initial_period = dates(1,1);
-options_.dataset.firstobs = options_.initial_period;
-options_.dataset.lastobs = NaN;
+estimation_info.joint_parameter_prior_index = {};
+estimation_info.joint_parameter = {'index','domain','interval','mean','median','mode','shape','shift','stdev','truncate','variance'};
+options_.initial_period = NaN; %dates(1,1);
+options_.dataset.file = [];
+options_.dataset.series = [];
+options_.dataset.firstobs = dates();
+options_.dataset.lastobs = dates();
 options_.dataset.nobs = NaN;
-options_.dataset.xls_sheet = NaN;
-options_.dataset.xls_range = NaN;
+options_.dataset.xls_sheet = [];
+options_.dataset.xls_range = [];
 options_.Harvey_scale_factor = 10;
-options_.MaxNumberOfBytes = 1e6;
+options_.MaxNumberOfBytes = 1e8;
 options_.MaximumNumberOfMegaBytes = 111;
-options_.PosteriorSampleSize = 1000;
 options_.analytic_derivation = 0;
 options_.analytic_derivation_mode = 0;
 options_.bayesian_irf = 0;
@@ -361,17 +415,23 @@ options_.bayesian_th_moments = 0;
 options_.diffuse_filter = 0;
 options_.filter_step_ahead = [];
 options_.filtered_vars = 0;
-options_.first_obs = 1;
+options_.smoothed_state_uncertainty = 0;
+options_.first_obs = NaN;
+options_.nobs = NaN;
 options_.kalman_algo = 0;
-options_.fast_kalman = 0;
+options_.fast_kalman_filter = 0;
 options_.kalman_tol = 1e-10;
+options_.kalman.keep_kalman_algo_if_singularity_is_detected = 0;
+options_.diffuse_kalman_tol = 1e-6;
 options_.use_univariate_filters_if_singularity_is_detected = 1;
 options_.riccati_tol = 1e-6;
 options_.lik_algo = 1;
 options_.lik_init = 1;
 options_.load_mh_file = 0;
+options_.load_results_after_load_mh = 0;
 options_.logdata = 0;
 options_.loglinear = 0;
+options_.linear_approximation = 0;
 options_.logged_steady_state = 0;
 options_.mh_conf_sig = 0.90;
 options_.prior_interval = 0.90;
@@ -385,6 +445,14 @@ options_.mh_replic = 20000;
 options_.recursive_estimation_restart = 0;
 options_.MCMC_jumping_covariance='hessian';
 options_.use_calibration_initialization = 0;
+options_.endo_vars_for_moment_computations_in_estimation=[];
+
+% Run optimizer silently
+options_.silent_optimizer=0;
+
+% Prior restrictions
+options_.prior_restrictions.status = 0;
+options_.prior_restrictions.routine = [];
 
 options_.mode_compute = 4;
 options_.mode_file = '';
@@ -397,14 +465,40 @@ options_.prefilter = 0;
 options_.presample = 0;
 options_.prior_trunc = 1e-10;
 options_.smoother = 0;
-options_.student_degrees_of_freedom = 3;
+options_.posterior_max_subsample_draws = 1200;
 options_.sub_draws = [];
-options_.use_mh_covariance_matrix = 0;
-options_.gradient_method = 2;
-options_.gradient_epsilon = 1e-6;
-options_.posterior_sampling_method = 'random_walk_metropolis_hastings';
-options_.proposal_distribution = 'rand_multivariate_normal';
-options_.student_degrees_of_freedom = 3;
+% options_.use_mh_covariance_matrix = 0;
+options_.gradient_method = 2; %used by csminwel and newrat
+options_.gradient_epsilon = 1e-6; %used by csminwel and newrat
+options_.posterior_sampler_options.sampling_opt = []; %extended set of options for individual posterior samplers
+                                                      % Random Walk Metropolis-Hastings
+options_.posterior_sampler_options.posterior_sampling_method = 'random_walk_metropolis_hastings';
+options_.posterior_sampler_options.rwmh.proposal_distribution = 'rand_multivariate_normal';
+options_.posterior_sampler_options.rwmh.student_degrees_of_freedom = 3;
+options_.posterior_sampler_options.rwmh.use_mh_covariance_matrix=0;
+options_.posterior_sampler_options.rwmh.save_tmp_file=0;
+% Tailored Random Block Metropolis-Hastings
+options_.posterior_sampler_options.tarb.proposal_distribution = 'rand_multivariate_normal';
+options_.posterior_sampler_options.tarb.student_degrees_of_freedom = 3;
+options_.posterior_sampler_options.tarb.mode_compute=4;
+options_.posterior_sampler_options.tarb.new_block_probability=0.25; %probability that next parameter belongs to new block
+options_.posterior_sampler_options.tarb.optim_opt=''; %probability that next parameter belongs to new block
+options_.posterior_sampler_options.tarb.save_tmp_file=1;
+% Slice
+options_.posterior_sampler_options.slice.proposal_distribution = '';
+options_.posterior_sampler_options.slice.rotated=0;
+options_.posterior_sampler_options.slice.slice_initialize_with_mode=0;
+options_.posterior_sampler_options.slice.use_mh_covariance_matrix=0;
+options_.posterior_sampler_options.slice.WR=[];
+options_.posterior_sampler_options.slice.mode_files=[];
+options_.posterior_sampler_options.slice.mode=[];
+options_.posterior_sampler_options.slice.initial_step_size=0.8;
+options_.posterior_sampler_options.slice.save_tmp_file=1;
+% Independent Metropolis-Hastings
+options_.posterior_sampler_options.imh.proposal_distribution = 'rand_multivariate_normal';
+options_.posterior_sampler_options.imh.use_mh_covariance_matrix=0;
+options_.posterior_sampler_options.imh.save_tmp_file=0;
+
 options_.trace_plot_ma = 200;
 options_.mh_autocorrelation_function_size = 30;
 options_.plot_priors = 1;
@@ -424,15 +518,18 @@ end
 options_.filter_covariance = 0;
 options_.filter_decomposition = 0;
 options_.selected_variables_only = 0;
+options_.contemporaneous_correlation = 0;
 options_.initialize_estimated_parameters_with_the_prior_mode = 0;
-options_.estimation_dll = 0;
-% Misc
-options_.conf_sig = 0.6;
+options_.estimation.moments_posterior_density.indicator = 1;
+options_.estimation.moments_posterior_density.gridpoints = 2^9;
+options_.estimation.moments_posterior_density.bandwidth = 0; % Rule of thumb optimal bandwidth parameter.
+options_.estimation.moments_posterior_density.kernel_function = 'gaussian'; % Gaussian kernel for Fast Fourrier Transform approximaton.
+                                                                            % Misc
+                                                                            % options_.conf_sig = 0.6;
 oo_.exo_simul = [];
 oo_.endo_simul = [];
 ys0_ = [];
 ex0_ = [];
-ex_det0_ = [];
 oo_.dr = [];
 oo_.exo_steady_state = [];
 oo_.exo_det_steady_state = [];
@@ -440,24 +537,71 @@ oo_.exo_det_simul = [];
 
 M_.params = [];
 M_.endo_histval = [];
+M_.exo_histval = [];
+M_.exo_det_histval = [];
 M_.Correlation_matrix = [];
 M_.Correlation_matrix_ME = [];
+M_.parameter_used_with_lead_lag = false;
 
-% homotopy
+M_.xref1.param = {};
+M_.xref1.endo = {};
+M_.xref1.exo = {};
+M_.xref1.exo_det = {};
+
+M_.xref2.param = {};
+M_.xref2.endo = {};
+M_.xref2.exo = {};
+M_.xref2.exo_det = {};
+
+M_.osr.param_names={};
+M_.osr.param_indices=[];
+M_.osr.param_bounds=[];
+M_.osr.variable_weights=[];
+M_.osr.variable_indices =[];
+
+% homotopy for steady state
 options_.homotopy_mode = 0;
 options_.homotopy_steps = 1;
 options_.homotopy_force_continue = 0;
 
+% numerical hessian
+hessian.use_penalized_objective = false;
+
+% Robust prediction error covariance (kalman filter)
+options_.rescale_prediction_error_covariance = false;
+
+options_.hessian = hessian;
+
+%csminwel optimization routine
+csminwel.tolerance.f=1e-7;
+csminwel.maxiter=1000;
+csminwel.verbosity=1;
+csminwel.Save_files=1;
+
+options_.csminwel=csminwel;
+
+%newrat optimization routine
+newrat.hess=1; % dynare numerical hessian
+newrat.tolerance.f=1e-5;
+newrat.tolerance.f_analytic=1e-7;
+newrat.maxiter=1000;
+newrat.verbosity=1;
+newrat.Save_files=1;
+
+options_.newrat=newrat;
+
 % Simplex optimization routine (variation on Nelder Mead algorithm).
 simplex.tolerance.x = 1e-4;
 simplex.tolerance.f = 1e-4;
 simplex.maxiter = 5000;
 simplex.maxfcallfactor = 500;
 simplex.maxfcall = [];
+simplex.verbosity = 2;
+simplex.delta_factor=0.05;
 options_.simplex = simplex;
 
 % CMAES optimization routine.
-cmaes.SaveVariables='off';
+cmaes.SaveVariables='on';
 cmaes.DispFinal='on';
 cmaes.WarnOnEqualFunctionValues='no';
 cmaes.DispModulo='10';
@@ -465,6 +609,7 @@ cmaes.LogModulo='0';
 cmaes.LogTime='0';
 cmaes.TolFun = 1e-7;
 cmaes.TolX = 1e-7;
+cmaes.Resume = 0;
 options_.cmaes = cmaes;
 
 % simpsa optimization routine.
@@ -483,6 +628,47 @@ simpsa.MAX_FUN_EVALS = 20000;
 simpsa.DISPLAY = 'iter';
 options_.simpsa = simpsa;
 
+%solveopt optimizer
+solveopt.minimizer_indicator=-1; %use minimizer
+solveopt.TolX=1e-6; %accuracy of argument
+solveopt.TolFun=1e-6; %accuracy of function
+solveopt.MaxIter=15000;
+solveopt.verbosity=1;
+solveopt.TolXConstraint=1.e-8;
+solveopt.SpaceDilation=2.5;
+solveopt.LBGradientStep=1.e-11;
+options_.solveopt=solveopt;
+
+%simulated annealing
+options_.saopt.neps=10;
+options_.saopt.maximizer_indicator=0;
+options_.saopt.rt=0.10;
+options_.saopt.MaxIter=100000;
+options_.saopt.verbosity=1;
+options_.saopt.TolFun=1.0e-8;
+options_.saopt.initial_temperature=15;
+options_.saopt.ns=10;
+options_.saopt.nt=10;
+options_.saopt.step_length_c=0.1;
+options_.saopt.initial_step_length=1;
+
+% particleswarm (global optimization toolbox needed)
+particleswarm.Display = 'iter';
+particleswarm.DisplayInterval = 1;
+particleswarm.FunctionTolerance = 1e-6;
+particleswarm.FunValCheck = 'on';
+particleswarm.HybridFcn = [];
+particleswarm.InertiaRange = [0.1, 1.1];
+particleswarm.MaxIterations = 100000;
+particleswarm.MaxStallIterations = 20;
+particleswarm.MaxStallTime = Inf;
+particleswarm.MaxTime = Inf;
+particleswarm.MinNeighborsFraction = .25;
+particleswarm.ObjectiveLimit = -Inf;
+particleswarm.UseParallel = false;
+particleswarm.UseVectorized = false;
+options_.particleswarm = particleswarm;
+
 % prior analysis
 options_.prior_mc = 20000;
 options_.prior_analysis_endo_var_list = [];
@@ -529,9 +715,7 @@ options_.dr_logarithmic_reduction_tol = 1e-12;
 options_.dr_logarithmic_reduction_maxiter = 100;
 
 % dates for historical time series
-options_.initial_date.freq = 1;
-options_.initial_date.period = 1;
-options_.initial_date.subperiod = 0;
+options_.initial_date = dates();
 
 % discretionary policy
 options_.discretionary_policy = 0;
@@ -539,6 +723,15 @@ options_.discretionary_tol = 1e-7;
 
 % Shock decomposition
 options_.parameter_set = [];
+options_.use_shock_groups = '';
+options_.shock_decomp.colormap = '';
+options_.shock_decomp.init_state = 0;
+
+% Shock decomposition realtime
+options_.shock_decomp.forecast = 0;
+options_.shock_decomp.presample = NaN;
+options_.shock_decomp.save_realtime = 0; % saves memory
+options_ = set_default_plot_shock_decomposition_options(options_);
 
 % Nonlinearfilters
 options_.nonlinear_filter = [];
@@ -597,11 +790,10 @@ options_.risky_steadystate = 0;
 % endogenous prior
 options_.endogenous_prior = 0;
 options_.endogenous_prior_restrictions.irf={};
+options_.endogenous_prior_restrictions.moment={};
 
 % OSR Optimal Simple Rules
-options_.osr.tolf=1e-7;
-options_.osr.maxit=1000;
-options_.osr.verbose=2;
+options_.osr.opt_algo=4;
 
 % use GPU
 options_.gpu = 0;
@@ -609,6 +801,27 @@ options_.gpu = 0;
 %Geweke convergence diagnostics
 options_.convergence.geweke.taper_steps=[4 8 15];
 options_.convergence.geweke.geweke_interval=[0.2 0.5];
+%Raftery/Lewis convergence diagnostics;
+options_.convergence.rafterylewis.indicator=0;
+options_.convergence.rafterylewis.qrs=[0.025 0.005 0.95];
+
+% Options for lmmcp solver
+options_.lmmcp.status = 0;
+
+% Options for lcppath solver
+options_.lcppath.A = [];
+options_.lcppath.b = [];
+options_.lcppath.t = [];
+options_.lcppath.mu0 = [];
+
+% Options for mcppath solver
+options_.mcppath.A = [];
+options_.mcppath.b = [];
+options_.mcppath.t = [];
+options_.mcppath.mu0 = [];
+
+%Figure options
+options_.figures.textwidth=0.8;
 
 % initialize persistent variables in priordens()
 priordens([],[],[],[],[],[],1);
@@ -618,6 +831,7 @@ dyn_first_order_solver();
 % Set dynare random generator and seed.
 set_dynare_seed('default');
 
+
 % Create directories
 [junk,junk]=mkdir(M_.fname);
 [junk,junk]=mkdir([M_.fname '/Output']);
@@ -626,4 +840,3 @@ set_dynare_seed('default');
 if isfield(options_, 'global_init_file')
     run(options_.global_init_file);
 end
-
