@@ -135,11 +135,7 @@ switch minimizer_algorithm
         simulated_annealing(objective_function,start_par_value,sa_options,LB,UB,varargin{:});
   case 3
     if isoctave && ~user_has_octave_forge_package('optim')
-        try
-            pkg load optim
-        catch
-            error('Optimization algorithm 3 requires the optim package')
-        end
+        error('Optimization algorithm 3 requires the optim package')
     elseif ~isoctave && ~user_has_matlab_license('optimization_toolbox')
         error('Optimization algorithm 3 requires the Optimization Toolbox')
     end
@@ -299,14 +295,14 @@ switch minimizer_algorithm
               case 'InitialSimplexSize'
                 simplexOptions.delta_factor = options_list{i,2};
               case 'verbosity'
-                simplexOptions.verbose = options_list{i,2};
+                simplexOptions.verbosity = options_list{i,2};
               otherwise
                 warning(['simplex: Unknown option (' options_list{i,1} ')!'])
             end
         end
     end
     if options_.silent_optimizer
-        simplexOptions.verbose = options_list{i,2};
+        simplexOptions.verbosity = 0;
     end
     [opt_par_values,fval,exitflag] = simplex_optimization_routine(objective_function,start_par_value,simplexOptions,parameter_names,varargin{:});
   case 9
