@@ -1,19 +1,20 @@
-function [i_var,nvar] = varlist_indices(sublist,list)
-% function [i_var,nvar] = varlist_indices(sublist,list)
+function [i_var,nvar,index_uniques] = varlist_indices(sublist,list)
+% function [i_var,nvar,index_uniques] = varlist_indices(sublist,list)
 % returns the indices of a list of endogenous variables
 %
 % INPUT
 %   sublist:    sublist of variables
-%   list:       list of variables 
+%   list:       list of variables
 %
 % OUTPUT
 %   i_var:      variable indices in M_.endo_names
 %   nvar:       number of variables in varlist
+%   index_uniqes: indices of unique elements in varlist
 %
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2010-2013 Dynare Team
+% Copyright (C) 2010-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -52,8 +53,6 @@ else
     end
 end
 
-nvar = length(i_var);
-
 if ~all(check)
     k = find(~check);
     tempstring = 'The following symbols are not endogenous variables: ';
@@ -62,3 +61,19 @@ if ~all(check)
     end
     error(tempstring)
 end
+
+nvar = length(i_var);
+[i_var_unique,index_uniques,junk] = unique(i_var,'first');
+index_uniques =sort(index_uniques);
+i_var_unique =i_var(index_uniques);
+
+if length(i_var_unique)~=nvar
+    k = find(~ismember(1:nvar,index_uniques));
+    tempstring = 'The following symbols are specified twice in the variable list and are considered only once: ';
+    for ii = 1:length(k)
+        tempstring = [ tempstring, deblank(sublist(k(ii),:)), ' ' ];
+    end
+    warning('%s\n',tempstring)
+    i_var=i_var_unique;
+    nvar = length(i_var);
+end
