@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2013 Dynare Team
+ * Copyright (C) 2010-2017 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -40,13 +40,24 @@ Hook::Hook(string &global_init_file_arg)
   hooks["global_init_file"] = global_init_file_arg;
 }
 
+Path::Path(vector<string> &includepath_arg)
+{
+  if (includepath_arg.empty())
+    {
+      cerr << "ERROR: The Path must have an Include argument." << endl;
+      exit(EXIT_FAILURE);
+    }
+  paths["include"] = includepath_arg;
+}
+
 SlaveNode::SlaveNode(string &computerName_arg, string port_arg, int minCpuNbr_arg, int maxCpuNbr_arg, string &userName_arg,
                      string &password_arg, string &remoteDrive_arg, string &remoteDirectory_arg,
-                     string &dynarePath_arg, string &matlabOctavePath_arg, bool singleCompThread_arg,
+                     string &dynarePath_arg, string &matlabOctavePath_arg, bool singleCompThread_arg, int numberOfThreadsPerJob_arg,
                      string &operatingSystem_arg) :
   computerName(computerName_arg), port(port_arg), minCpuNbr(minCpuNbr_arg), maxCpuNbr(maxCpuNbr_arg), userName(userName_arg),
   password(password_arg), remoteDrive(remoteDrive_arg), remoteDirectory(remoteDirectory_arg), dynarePath(dynarePath_arg),
-  matlabOctavePath(matlabOctavePath_arg), singleCompThread(singleCompThread_arg), operatingSystem(operatingSystem_arg)
+  matlabOctavePath(matlabOctavePath_arg), singleCompThread(singleCompThread_arg), numberOfThreadsPerJob(numberOfThreadsPerJob_arg),
+  operatingSystem(operatingSystem_arg)
 {
   if (computerName.empty())
     {
@@ -91,7 +102,7 @@ ConfigFile::getConfigFileInfo(const string &config_file)
 
   if (config_file.empty())
     {
-      string defaultConfigFile ("");
+      string defaultConfigFile("");
       // Test OS and try to open default file
 #if defined(_WIN32) || defined(__CYGWIN32__)
       if (getenv("APPDATA") == NULL)
@@ -111,72 +122,80 @@ ConfigFile::getConfigFileInfo(const string &config_file)
           defaultConfigFile += "\\dynare.ini";
         }
 #else
-        if (getenv("HOME") == NULL)
-          {
-            if (parallel || parallel_test)
-              cerr << "ERROR: ";
-            else
-              cerr << "WARNING: ";
-            cerr << "HOME environment variable not found." << endl;
-            if (parallel || parallel_test)
-              exit(EXIT_FAILURE);
-          }
-        else
-          {
-            defaultConfigFile += getenv("HOME");
-            defaultConfigFile += "/.dynare";
-          }
-#endif
-        configFile = new ifstream(defaultConfigFile.c_str(), fstream::in);
-        if (!configFile->is_open())
+      if (getenv("HOME") == NULL)
+        {
           if (parallel || parallel_test)
-            {
-              cerr << "ERROR: Could not open the default config file (" << defaultConfigFile << ")" << endl;
-              exit(EXIT_FAILURE);
-            }
+            cerr << "ERROR: ";
           else
-            return;
-      }
-    else
-      {
-        configFile = new ifstream(config_file.c_str(), fstream::in);
-        if (!configFile->is_open())
+            cerr << "WARNING: ";
+          cerr << "HOME environment variable not found." << endl;
+          if (parallel || parallel_test)
+            exit(EXIT_FAILURE);
+        }
+      else
+        {
+          defaultConfigFile += getenv("HOME");
+          defaultConfigFile += "/.dynare";
+        }
+#endif
+      configFile = new ifstream(defaultConfigFile.c_str(), fstream::in);
+      if (!configFile->is_open())
+        if (parallel || parallel_test)
           {
-            cerr << "ERROR: Couldn't open file " << config_file << endl;;
+            cerr << "ERROR: Could not open the default config file (" << defaultConfigFile << ")" << endl;
             exit(EXIT_FAILURE);
           }
-      }
-
+        else
+          return;
+    }
+  else
+    {
+      configFile = new ifstream(config_file.c_str(), fstream::in);
+      if (!configFile->is_open())
+        {
+          cerr << "ERROR: Couldn't open file " << config_file << endl;;
+          exit(EXIT_FAILURE);
+        }
+    }
 
   string name, computerName, port, userName, password, remoteDrive,
     remoteDirectory, dynarePath, matlabOctavePath, operatingSystem,
     global_init_file;
+  vector<string> includepath;
   int minCpuNbr = 0, maxCpuNbr = 0;
-  bool singleCompThread = true;
+  int numberOfThreadsPerJob = 1;
+  bool singleCompThread = false;
   member_nodes_t member_nodes;
 
   bool inHooks = false;
   bool inNode = false;
   bool inCluster = false;
+  bool inPaths = false;
   while (configFile->good())
     {
       string line;
       getline(*configFile, line);
       trim(line);
-      if (line.empty())
+      if (line.empty() || !line.compare(0, 1, "#"))
         continue;
 
-      if (!line.compare("[node]") || !line.compare("[cluster]") || !line.compare("[hooks]"))
+      if (!line.compare("[node]")
+          || !line.compare("[cluster]")
+          || !line.compare("[hooks]")
+          || !line.compare("[paths]"))
         {
           if (!global_init_file.empty())
             // we were just in [hooks]
             addHooksConfFileElement(global_init_file);
+          else if (!includepath.empty())
+            // we were just in [paths]
+            addPathsConfFileElement(includepath);
           else
             // we were just in [node] or [cluster]
             addParallelConfFileElement(inNode, inCluster, member_nodes, name,
                                        computerName, port, minCpuNbr, maxCpuNbr, userName,
                                        password, remoteDrive, remoteDirectory,
-                                       dynarePath, matlabOctavePath, singleCompThread,
+                                       dynarePath, matlabOctavePath, singleCompThread, numberOfThreadsPerJob,
                                        operatingSystem);
 
           //! Reset communication vars / option defaults
@@ -185,26 +204,37 @@ ConfigFile::getConfigFileInfo(const string &config_file)
               inHooks = true;
               inNode = false;
               inCluster = false;
+              inPaths = false;
+            }
+          else if (!line.compare("[node]"))
+            {
+              inHooks = false;
+              inNode = true;
+              inCluster = false;
+              inPaths = false;
+            }
+          else if (!line.compare("[paths]"))
+            {
+              inHooks = false;
+              inNode = false;
+              inCluster = false;
+              inPaths = true;
             }
           else
-            if (!line.compare("[node]"))
-              {
-                inHooks = false;
-                inNode = true;
-                inCluster = false;
-              }
-            else
-              {
-                inHooks = false;
-                inNode = false;
-                inCluster = true;
-              }
+            {
+              inHooks = false;
+              inNode = false;
+              inCluster = true;
+              inPaths = false;
+            }
 
           name = userName = computerName = port = password = remoteDrive
             = remoteDirectory = dynarePath = matlabOctavePath
             = operatingSystem = global_init_file = "";
+          includepath.clear();
           minCpuNbr = maxCpuNbr = 0;
-          singleCompThread = true;
+          numberOfThreadsPerJob = 1;
+          singleCompThread = false;
           member_nodes.clear();
         }
       else
@@ -233,6 +263,30 @@ ConfigFile::getConfigFileInfo(const string &config_file)
                 cerr << "ERROR: Unrecognized option " << tokenizedLine.front() << " in [hooks] block." << endl;
                 exit(EXIT_FAILURE);
               }
+          else if (inPaths)
+            if (!tokenizedLine.front().compare("Include"))
+              if (includepath.empty())
+                {
+                  vector<string> tokenizedPath;
+                  split(tokenizedPath, tokenizedLine.back(), is_any_of(":"), token_compress_on);
+                  for (vector<string>::iterator it = tokenizedPath.begin();
+                       it != tokenizedPath.end(); it++)
+                    if (!it->empty())
+                      {
+                        trim(*it);
+                        includepath.push_back(*it);
+                      }
+                }
+              else
+                {
+                  cerr << "ERROR: May not have more than one Include option in [paths] block." << endl;
+                  exit(EXIT_FAILURE);
+                }
+            else
+              {
+                cerr << "ERROR: Unrecognized option " << tokenizedLine.front() << " in [paths] block." << endl;
+                exit(EXIT_FAILURE);
+              }
           else
             if (!tokenizedLine.front().compare("Name"))
               name = tokenizedLine.back();
@@ -297,6 +351,8 @@ ConfigFile::getConfigFileInfo(const string &config_file)
               dynarePath = tokenizedLine.back();
             else if (!tokenizedLine.front().compare("MatlabOctavePath"))
               matlabOctavePath = tokenizedLine.back();
+            else if (!tokenizedLine.front().compare("NumberOfThreadsPerJob"))
+              numberOfThreadsPerJob = atoi(tokenizedLine.back().c_str());
             else if (!tokenizedLine.front().compare("SingleCompThread"))
               if (tokenizedLine.back().compare("true") == 0)
                 singleCompThread = true;
@@ -318,7 +374,7 @@ ConfigFile::getConfigFileInfo(const string &config_file)
                 for (tokenizer<char_separator<char> >::iterator it = tokens.begin();
                      it != tokens.end(); it++)
                   {
-                    string token (*it);
+                    string token(*it);
                     if (token.compare("(") == 0)
                       {
                         begin_weight = true;
@@ -379,12 +435,15 @@ ConfigFile::getConfigFileInfo(const string &config_file)
 
   if (!global_init_file.empty())
     addHooksConfFileElement(global_init_file);
+  else if (!includepath.empty())
+    addPathsConfFileElement(includepath);
   else
     addParallelConfFileElement(inNode, inCluster, member_nodes, name,
                                computerName, port, minCpuNbr, maxCpuNbr, userName,
                                password, remoteDrive, remoteDirectory,
-                               dynarePath, matlabOctavePath, singleCompThread,
+                               dynarePath, matlabOctavePath, singleCompThread, numberOfThreadsPerJob,
                                operatingSystem);
+
   configFile->close();
   delete configFile;
 }
@@ -401,11 +460,23 @@ ConfigFile::addHooksConfFileElement(string &global_init_file)
     hooks.push_back(new Hook(global_init_file));
 }
 
+void
+ConfigFile::addPathsConfFileElement(vector<string> &includepath)
+{
+  if (includepath.empty())
+    {
+      cerr << "ERROR: The path to be included must be passed to the Include option." << endl;
+      exit(EXIT_FAILURE);
+    }
+  else
+    paths.push_back(new Path(includepath));
+}
+
 void
 ConfigFile::addParallelConfFileElement(bool inNode, bool inCluster, member_nodes_t member_nodes,
                                        string &name, string &computerName, string port, int minCpuNbr, int maxCpuNbr, string &userName,
                                        string &password, string &remoteDrive, string &remoteDirectory,
-                                       string &dynarePath, string &matlabOctavePath, bool singleCompThread,
+                                       string &dynarePath, string &matlabOctavePath, bool singleCompThread, int numberOfThreadsPerJob,
                                        string &operatingSystem)
 {
   //! ADD NODE
@@ -424,7 +495,8 @@ ConfigFile::addParallelConfFileElement(bool inNode, bool inCluster, member_nodes
       else
         slave_nodes[name] = new SlaveNode(computerName, port, minCpuNbr, maxCpuNbr, userName,
                                           password, remoteDrive, remoteDirectory, dynarePath,
-                                          matlabOctavePath, singleCompThread, operatingSystem);
+                                          matlabOctavePath, singleCompThread, numberOfThreadsPerJob,
+                                          operatingSystem);
   //! ADD CLUSTER
   else if (inCluster)
     if (minCpuNbr > 0 || maxCpuNbr > 0 || !userName.empty()
@@ -452,10 +524,10 @@ void
 ConfigFile::checkPass(WarningConsolidation &warnings) const
 {
   bool global_init_file_declared = false;
-  for (vector<Hook *>::const_iterator it = hooks.begin() ; it != hooks.end(); it++)
+  for (vector<Hook *>::const_iterator it = hooks.begin(); it != hooks.end(); it++)
     {
       const map <string, string> hookmap = (*it)->get_hooks();
-      for (map <string, string>::const_iterator mapit = hookmap.begin() ; mapit != hookmap.end(); mapit++)
+      for (map <string, string>::const_iterator mapit = hookmap.begin(); mapit != hookmap.end(); mapit++)
         if (mapit->first.compare("global_init_file") == 0)
           if (global_init_file_declared == true)
             {
@@ -609,13 +681,27 @@ ConfigFile::transformPass()
     it->second /= weight_denominator;
 }
 
+vector<string>
+ConfigFile::getIncludePaths() const
+{
+  vector<string> include_paths;
+  for (vector<Path *>::const_iterator it = paths.begin(); it != paths.end(); it++)
+    {
+      map <string, vector<string> > pathmap = (*it)->get_paths();
+      for (map <string, vector<string> >::const_iterator mapit = pathmap.begin(); mapit != pathmap.end(); mapit++)
+        for (vector<string>::const_iterator vecit = mapit->second.begin(); vecit != mapit->second.end(); vecit++)
+          include_paths.push_back(*vecit);
+    }
+  return include_paths;
+}
+
 void
 ConfigFile::writeHooks(ostream &output) const
 {
-  for (vector<Hook *>::const_iterator it = hooks.begin() ; it != hooks.end(); it++)
+  for (vector<Hook *>::const_iterator it = hooks.begin(); it != hooks.end(); it++)
     {
       map <string, string> hookmap = (*it)->get_hooks();
-      for (map <string, string>::const_iterator mapit = hookmap.begin() ; mapit != hookmap.end(); mapit++)
+      for (map <string, string>::const_iterator mapit = hookmap.begin(); mapit != hookmap.end(); mapit++)
         output << "options_." << mapit->first << " = '" << mapit->second << "';" << endl;
     }
 }
@@ -665,7 +751,8 @@ ConfigFile::writeCluster(ostream &output) const
              << "'DynarePath', '" << it->second->dynarePath << "', "
              << "'MatlabOctavePath', '" << it->second->matlabOctavePath << "', "
              << "'OperatingSystem', '" << it->second->operatingSystem << "', "
-             << "'NodeWeight', '" << (cluster_it->second->member_nodes.find(it->first))->second << "', ";
+             << "'NodeWeight', '" << (cluster_it->second->member_nodes.find(it->first))->second << "', "
+             << "'NumberOfThreadsPerJob', " << it->second->numberOfThreadsPerJob << ", ";
 
       if (it->second->singleCompThread)
         output << "'SingleCompThread', 'true');" << endl;
