@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Dynare Team
+ * Copyright (C) 2003-2016 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -72,6 +72,16 @@ DataTree::AddVariableInternal(int symb_id, int lag)
     return new VariableNode(*this, symb_id, lag);
 }
 
+bool
+DataTree::ParamUsedWithLeadLagInternal() const
+{
+  for (variable_node_map_t::const_iterator it = variable_node_map.begin();
+       it != variable_node_map.end(); it++)
+    if (symbol_table.getType(it->first.first) == eParameter && it->first.second != 0)
+      return true;
+  return false;
+}
+
 VariableNode *
 DataTree::AddVariable(int symb_id, int lag)
 {
@@ -168,7 +178,7 @@ DataTree::AddTimes(expr_t iArg1, expr_t iArg2)
 }
 
 expr_t
-DataTree::AddDivide(expr_t iArg1, expr_t iArg2)
+DataTree::AddDivide(expr_t iArg1, expr_t iArg2) throw (DivisionByZeroException)
 {
   if (iArg2 == One)
     return iArg1;
@@ -177,7 +187,7 @@ DataTree::AddDivide(expr_t iArg1, expr_t iArg2)
   if (iArg2 == Zero)
     {
       cerr << "ERROR: Division by zero!" << endl;
-      exit(EXIT_FAILURE);
+      throw DivisionByZeroException();
     }
 
   if (iArg1 == Zero)
@@ -674,9 +684,9 @@ DataTree::writePowerDerivCHeader(ostream &output) const
 }
 
 void
-DataTree::writePowerDeriv(ostream &output, bool use_dll) const
+DataTree::writePowerDeriv(ostream &output) const
 {
-  if (use_dll && isBinaryOpUsed(oPowerDeriv))
+  if (isBinaryOpUsed(oPowerDeriv))
     output << "/*" << endl
            << " * The k-th derivative of x^p" << endl
            << " */" << endl
@@ -697,3 +707,48 @@ DataTree::writePowerDeriv(ostream &output, bool use_dll) const
            << "    }" << endl
            << "}" << endl;
 }
+
+void
+DataTree::writeNormcdfCHeader(ostream &output) const
+{
+#if defined(_WIN32) || defined(__CYGWIN32__) || defined(__MINGW32__)
+  if (isTrinaryOpUsed(oNormcdf))
+    output << "#ifdef _MSC_VER" << endl
+           << "double normcdf(double);" << endl
+           << "#endif" << endl;
+#endif
+}
+
+void
+DataTree::writeNormcdf(ostream &output) const
+{
+#if defined(_WIN32) || defined(__CYGWIN32__) || defined(__MINGW32__)
+  if (isTrinaryOpUsed(oNormcdf))
+    output << endl
+           << "#ifdef _MSC_VER" << endl
+           << "/*" << endl
+           << " * Define normcdf for MSVC compiler" << endl
+           << " */" << endl
+           << "double normcdf(double x)" << endl
+           << "{" << endl
+           << "#if _MSC_VER >= 1700" << endl
+           << "  return 0.5 * erfc(-x * M_SQRT1_2);" << endl
+           << "#else" << endl
+           << "  // From http://www.johndcook.com/blog/cpp_phi" << endl
+           << "  double a1 =  0.254829592;" << endl
+           << "  double a2 = -0.284496736;" << endl
+           << "  double a3 =  1.421413741;" << endl
+           << "  double a4 = -1.453152027;" << endl
+           << "  double a5 =  1.061405429;" << endl
+           << "  double p  =  0.3275911;" << endl
+           << "  int sign = (x < 0) ? -1 : 1;" << endl
+           << "  x = fabs(x)/sqrt(2.0);" << endl
+           << "  // From the Handbook of Mathematical Functions by Abramowitz and Stegun, formula 7.1.26" << endl
+           << "  double t = 1.0/(1.0 + p*x);" << endl
+           << "  double y = 1.0 - (((((a5*t + a4)*t) + a3)*t + a2)*t + a1)*t*exp(-x*x);" << endl
+           << "  return 0.5*(1.0 + sign*y);" << endl
+           << "#endif" << endl
+           << "}" << endl
+           << "#endif" << endl;
+#endif
+}
